# coding gbk
from distutils.core import setup

setup(
    name="baizhanMath2_1",
    version="1.0",
    description="3434",
    author="ztf",
    author_email="ztf@163.com",
    py_modules=["baizhanMath2.demo1","baizhanMath2.demo2"]
)